==> lokka-hoc-0.3.10.tgz: package/lib/lokkifyFactory.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

module.exports = function lokkifyFactory(lokkaClient, viewFramework) {

  if (!viewFramework && (typeof window === 'undefined' ? 'undefined' : _typeof(window)) !== undefined) {
    viewFramework = window.React || window.preact;

    if (!viewFramework) {
      throw new Error('No suitable view layer found in window (expect to have: React or preact)');
    }
  }

  var jsxRenderer = viewFramework.createElement || viewFramework.h;
  if (!jsxRenderer) {
    throw new Error('No suitable jsx function provided (expect to have: React or preact)');
  }

  function fetcher(query, vars) {
    return lokkaClient.query(query, vars);
  }

  function lokkify(ChildComponent, query) {
    var mutations = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

    var queryFunc = query;
    if (typeof query === 'string') {
      queryFunc = function queryFunc() {
        return query;
      };
    }

    return function (_viewFramework$Compon) {
      _inherits(LokkaHighOrderComponent, _viewFramework$Compon);

      function LokkaHighOrderComponent() {
        var _ref;

        _classCallCheck(this, LokkaHighOrderComponent);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        var _this = _possibleConstructorReturn(this, (_ref = LokkaHighOrderComponent.__proto__ || Object.getPrototypeOf(LokkaHighOrderComponent)).call.apply(_ref, [this].concat(args)));

        _this.state = {
          loading: true,
          mutate: function mutate(name, vars) {
            return mutations[name] && lokkaClient.mutate(mutations[name], vars);
          }
        };
        return _this;
      }

      _createClass(LokkaHighOrderComponent, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
          var _this2 = this;

          if (queryFunc(this.props) !== queryFunc(nextProps)) {
            setTimeout(function () {
              return _this2._refetch();
            });
          }
        }
      }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
          this.mounted = false;
        }
      }, {
        key: 'componentDidMount',
        value: function componentDidMount() {
          var _this3 = this;

          this.mounted = true;
          this.queryId = 0;
          var refetch = function refetch(vars) {
            var queryId = ++_this3.queryId;
            _this3.mounted && fetcher(queryFunc(_this3.props), vars || _this3.props).then(function (data) {
              _this3.mounted && queryId === _this3.queryId && _this3.setState({
                loading: false,
                refetch: refetch,
                errors: null,
                data: data
              });
            }, function (errors) {
              _this3.mounted && queryId === _this3.queryId && _this3.setState({
                loading: false,
                refetch: refetch,
                data: null,
                errors: [errors]
              });
            });
            _this3.setState({
              loading: true
            });
          };
          this._refetch = refetch;

          refetch();
        }
      }, {
        key: 'render',
        value: function render() {
          return jsxRenderer.apply(undefined, [ChildComponent, _extends({}, this.state, this.props)].concat(_toConsumableArray(this.props.children || [])));
        }
      }]);

      return LokkaHighOrderComponent;
    }(viewFramework.Component);
  }

  return lokkify;
};

==> lokka-hoc-0.3.11.tgz: package/lib/lokkifyFactory.js <==
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

module.exports = function lokkifyFactory(lokkaClient, viewFramework) {

  if (!viewFramework && (typeof window === 'undefined' ? 'undefined' : _typeof(window)) !== undefined) {
    viewFramework = window.React || window.preact;

    if (!viewFramework) {
      throw new Error('No suitable view layer found in window (expect to have: React or preact)');
    }
  }

  var jsxRenderer = viewFramework.createElement || viewFramework.h;
  if (!jsxRenderer) {
    throw new Error('No suitable jsx function provided (expect to have: React or preact)');
  }

  function fetcher(query, vars) {
    return lokkaClient.query(query, vars);
  }

  function lokkify(ChildComponent, query) {
    var mutations = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

    var queryFunc = query;
    if (typeof query === 'string') {
      queryFunc = function queryFunc() {
        return query;
      };
    }

    return function (_viewFramework$Compon) {
      _inherits(LokkaHighOrderComponent, _viewFramework$Compon);

      function LokkaHighOrderComponent() {
        var _ref;

        _classCallCheck(this, LokkaHighOrderComponent);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        var _this = _possibleConstructorReturn(this, (_ref = LokkaHighOrderComponent.__proto__ || Object.getPrototypeOf(LokkaHighOrderComponent)).call.apply(_ref, [this].concat(args)));

        _this.state = {
          loading: true,
          mutate: function mutate(name, vars) {
            return mutations[name] && lokkaClient.mutate(mutations[name], vars);
          }
        };
        return _this;
      }

      _createClass(LokkaHighOrderComponent, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
          var _this2 = this;

          setTimeout(function () {
            return _this2._refetch(nextProps);
          });
        }
      }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
          this.mounted = false;
        }
      }, {
        key: 'componentDidMount',
        value: function componentDidMount() {
          var _this3 = this;

          this.mounted = true;
          this.queryId = 0;
          var refetch = function refetch(vars) {
            var queryId = ++_this3.queryId;
            _this3.mounted && fetcher(queryFunc(_this3.props), vars || _this3.props).then(function (data) {
              _this3.mounted && queryId === _this3.queryId && _this3.setState({
                loading: false,
                refetch: refetch,
                errors: null,
                data: data
              });
            }, function (errors) {
              _this3.mounted && queryId === _this3.queryId && _this3.setState({
                loading: false,
                refetch: refetch,
                data: null,
                errors: [errors]
              });
            });
            _this3.setState({
              loading: true
            });
          };
          this._refetch = refetch;

          refetch();
        }
      }, {
        key: 'render',
        value: function render() {
          return jsxRenderer.apply(undefined, [ChildComponent, _extends({}, this.state, this.props)].concat(_toConsumableArray(this.props.children || [])));
        }
      }]);

      return LokkaHighOrderComponent;
    }(viewFramework.Component);
  }

  return lokkify;
};
